==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/inside/cluster/ClusterConstraints.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.cluster
{
	/// <exclude></exclude>
	public class ClusterConstraints : com.db4o.inside.cluster.ClusterConstraint, com.db4o.query.Constraints
	{
		public ClusterConstraints(com.db4o.cluster.Cluster cluster, com.db4o.query.Constraint[]
			 constraints) : base(cluster, constraints)
		{
		}

		public virtual com.db4o.query.Constraint[] toArray()
		{
			lock (_cluster)
			{
				com.db4o.foundation.Collection4 all = new com.db4o.foundation.Collection4();
				for (int i = 0; i < _constraints.Length; i++)
				{
					com.db4o.inside.cluster.ClusterConstraint c = (com.db4o.inside.cluster.ClusterConstraint
						)_constraints[i];
					for (int j = 0; j < c._constraints.Length; j++)
					{
						all.add(c._constraints[j]);
					}
				}
				com.db4o.query.Constraint[] res = new com.db4o.query.Constraint[all.size()];
				all.toArray(res);
				return res;
			}
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/inside/cluster/ClusterConstraints.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.cluster
{
	/// <exclude></exclude>
	public class ClusterConstraints : com.db4o.inside.cluster.ClusterConstraint, com.db4o.query.Constraints
	{
		public ClusterConstraints(com.db4o.cluster.Cluster cluster, com.db4o.query.Constraint[]
			 constraints) : base(cluster, constraints)
		{
		}

		public virtual com.db4o.query.Constraint[] ToArray()
		{
			lock (_cluster)
			{
				com.db4o.foundation.Collection4 all = new com.db4o.foundation.Collection4();
				for (int i = 0; i < _constraints.Length; i++)
				{
					com.db4o.inside.cluster.ClusterConstraint c = (com.db4o.inside.cluster.ClusterConstraint
						)_constraints[i];
					for (int j = 0; j < c._constraints.Length; j++)
					{
						all.Add(c._constraints[j]);
					}
				}
				com.db4o.query.Constraint[] res = new com.db4o.query.Constraint[all.Size()];
				all.ToArray(res);
				return res;
			}
		}
	}
}
